import { createApp, h } from 'vue';
import MessageBar from '@/components/MessageBar.vue';

const MessagePlugin = {
  install(app) {
    const showMessage = (type, message, action) => {
      const container = document.createElement('div');
      container.style.position = 'fixed';
      container.style.bottom = '20px';
      container.style.right = '20px';
      document.body.appendChild(container);

      const appInstance = createApp({
        render() {
          return h(MessageBar, { type, message, action });
        },
      });

      appInstance.mount(container);

      setTimeout(() => {
        appInstance.unmount();
        document.body.removeChild(container);
      }, 5000); // 自动卸载组件
    };

    app.config.globalProperties.$message = {
      info: (message, action) => showMessage('info', message, action),
      danger: (message, action) => showMessage('danger', message, action),
      warning: (message, action) => showMessage('warning', message, action),
    };
  },
};

export default MessagePlugin;
